@@ -9,15 +9,20 @@
 # import sys
 # sys.setrecursionlimit(n)
 
+from metafab_python.model.approve_ecosystem_game_request import ApproveEcosystemGameRequest
 from metafab_python.model.auth_game200_response import AuthGame200Response
 from metafab_python.model.auth_game200_response_all_of import AuthGame200ResponseAllOf
-from metafab_python.model.auth_game200_response_all_of1 import AuthGame200ResponseAllOf1
 from metafab_python.model.auth_player200_response import AuthPlayer200Response
+from metafab_python.model.auth_player200_response_all_of import AuthPlayer200ResponseAllOf
+from metafab_python.model.auth_profile200_response import AuthProfile200Response
 from metafab_python.model.batch_mint_collection_items_request import BatchMintCollectionItemsRequest
 from metafab_python.model.batch_transfer_collection_items_request import BatchTransferCollectionItemsRequest
 from metafab_python.model.batch_transfer_currency_request import BatchTransferCurrencyRequest
 from metafab_python.model.burn_collection_item_request import BurnCollectionItemRequest
 from metafab_python.model.burn_currency_request import BurnCurrencyRequest
+from metafab_python.model.collection_item import CollectionItem
+from metafab_python.model.collection_item_attributes_inner import CollectionItemAttributesInner
+from metafab_python.model.collection_item_attributes_inner_value import CollectionItemAttributesInnerValue
 from metafab_python.model.collection_model import CollectionModel
 from metafab_python.model.contract_model import ContractModel
 from metafab_python.model.create_collection200_response import CreateCollection200Response
@@ -30,13 +35,19 @@ from metafab_python.model.create_collection_request import CreateCollectionReque
 from metafab_python.model.create_contract_request import CreateContractRequest
 from metafab_python.model.create_currency200_response import CreateCurrency200Response
 from metafab_python.model.create_currency_request import CreateCurrencyRequest
+from metafab_python.model.create_ecosystem_request import CreateEcosystemRequest
 from metafab_python.model.create_game_request import CreateGameRequest
 from metafab_python.model.create_lootbox_manager200_response import CreateLootboxManager200Response
 from metafab_python.model.create_lootbox_manager_request import CreateLootboxManagerRequest
 from metafab_python.model.create_player_request import CreatePlayerRequest
+from metafab_python.model.create_profile_player_request import CreateProfilePlayerRequest
+from metafab_python.model.create_profile_request import CreateProfileRequest
 from metafab_python.model.create_shop200_response import CreateShop200Response
 from metafab_python.model.create_shop_request import CreateShopRequest
+from metafab_python.model.create_wallet_signature_request import CreateWalletSignatureRequest
 from metafab_python.model.currency_model import CurrencyModel
+from metafab_python.model.ecosystem_game_model import EcosystemGameModel
+from metafab_python.model.ecosystem_model import EcosystemModel
 from metafab_python.model.game_model import GameModel
 from metafab_python.model.get_collections200_response_inner import GetCollections200ResponseInner
 from metafab_python.model.get_collections200_response_inner_all_of import GetCollections200ResponseInnerAllOf
@@ -44,6 +55,7 @@ from metafab_python.model.get_currencies200_response_inner import GetCurrencies2
 from metafab_python.model.get_currency_fees200_response import GetCurrencyFees200Response
 from metafab_python.model.get_lootbox_managers200_response_inner import GetLootboxManagers200ResponseInner
 from metafab_python.model.get_player_data200_response import GetPlayerData200Response
+from metafab_python.model.get_profile_games200_response_inner import GetProfileGames200ResponseInner
 from metafab_python.model.get_shops200_response_inner import GetShops200ResponseInner
 from metafab_python.model.grant_collection_role_request import GrantCollectionRoleRequest
 from metafab_python.model.grant_currency_role_request import GrantCurrencyRoleRequest
@@ -52,9 +64,14 @@ from metafab_python.model.lootbox_manager_model import LootboxManagerModel
 from metafab_python.model.mint_collection_item_request import MintCollectionItemRequest
 from metafab_python.model.mint_currency_request import MintCurrencyRequest
 from metafab_python.model.player_model import PlayerModel
+from metafab_python.model.profile_model import ProfileModel
+from metafab_python.model.profile_permissions import ProfilePermissions
+from metafab_python.model.profile_permissions_value import ProfilePermissionsValue
+from metafab_python.model.public_ecosystem import PublicEcosystem
 from metafab_python.model.public_game import PublicGame
 from metafab_python.model.public_player import PublicPlayer
-from metafab_python.model.public_player_wallet import PublicPlayerWallet
+from metafab_python.model.public_player_custodial_wallet import PublicPlayerCustodialWallet
+from metafab_python.model.public_profile import PublicProfile
 from metafab_python.model.remove_player_connected_wallet_request import RemovePlayerConnectedWalletRequest
 from metafab_python.model.revoke_collection_role_request import RevokeCollectionRoleRequest
 from metafab_python.model.set_collection_approval_request import SetCollectionApprovalRequest
@@ -71,8 +88,16 @@ from metafab_python.model.transaction_model import TransactionModel
 from metafab_python.model.transfer_collection_item_request import TransferCollectionItemRequest
 from metafab_python.model.transfer_contract_ownership_request import TransferContractOwnershipRequest
 from metafab_python.model.transfer_currency_request import TransferCurrencyRequest
+from metafab_python.model.update_ecosystem_request import UpdateEcosystemRequest
+from metafab_python.model.update_game200_response import UpdateGame200Response
+from metafab_python.model.update_game200_response_all_of import UpdateGame200ResponseAllOf
 from metafab_python.model.update_game_request import UpdateGameRequest
+from metafab_python.model.update_player200_response import UpdatePlayer200Response
 from metafab_python.model.update_player_request import UpdatePlayerRequest
+from metafab_python.model.update_profile_player200_response import UpdateProfilePlayer200Response
+from metafab_python.model.update_profile_player200_response_all_of import UpdateProfilePlayer200ResponseAllOf
+from metafab_python.model.update_profile_player_request import UpdateProfilePlayerRequest
+from metafab_python.model.update_profile_request import UpdateProfileRequest
 from metafab_python.model.upgrade_contract_trusted_forwarder_request import UpgradeContractTrustedForwarderRequest
 from metafab_python.model.wallet_model import WalletModel
 from metafab_python.model.withdraw_from_shop_request import WithdrawFromShopRequest
